Page 24 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 24

Home

    The wicked, through the pride of his countenance,
    will not seek God: God in not in all his thoughts.
    Psalms 10:4

    He sitteth in the lurking places of the villages, in the
    secret places doth he murder the innocent: . . .

    nod ana

    To understand the establishment of a power as evil and
    extensive as Mystery Babylon, it is helpful to consider
    some secret societies and conspiracies that have
    determined the outcome of many historical events. Their
    existence is as old as mankind.

    secret

    some

    whatever end they may have been employed, the
    inspiration and methods of these mysterious associations
    which have played so important a part behind the scenes
    of the world's history will be found to have emanated
    from the lands where the first recorded acts of the great
    human drama were played out — Egypt, Babylon, Syria,

    19

    Chapter 4

    Secret Societies

    Psalms 10:8

    He lieth in wait secretly as a lion in his den...
    neat.

    Psalm 10:9

    that have

    The British historian, Nesta H. Webster, relates their

    beginning in this manner:

    The East is the cradle of secret societies. For